hash_code

Function hash_code 

pub fn hash_code(code: &str) -> String
Compute the SHA-256 hash of canonicalized code.

This is the same hash used in approval tokens. Clients can call this to verify their code will match the token before executing.