Module types

Module types 

Domain types for policy evaluation.

These types represent the entities used in Cedar policy evaluation. They are pure domain types with no AWS SDK dependency.

Structs

AuthorizationDecision
Authorization decision from policy evaluation.
OpenAPIServerEntity
Server configuration for OpenAPI Code Mode.
OperationEntity
Operation entity for policy evaluation.
ScriptEntity
Script entity for policy evaluation (OpenAPI Code Mode).
ServerConfigEntity
Server configuration for policy evaluation.
SqlServerEntity
Server configuration for SQL Code Mode.
StatementEntity
SQL statement entity for policy evaluation (SQL Code Mode).

Functions

get_baseline_policies
Get the baseline Cedar policies.
get_code_mode_schema_json
Get the Cedar schema in JSON format.
get_openapi_baseline_policies
Get baseline Cedar policies for OpenAPI Code Mode.
get_openapi_code_mode_schema_json
Get the Cedar schema for OpenAPI Code Mode in JSON format.
get_sql_baseline_policies
Get baseline Cedar policies for SQL Code Mode.
get_sql_code_mode_schema_json
Get the Cedar schema for SQL Code Mode in JSON format.
normalize_operation_format
Normalize an operation string to the canonical “METHOD:/path” format.
normalize_path_to_pattern
Normalize a path to a pattern by replacing numeric/UUID segments with *.