Domain types for policy evaluation.
These types represent the entities used in Cedar policy evaluation. They are pure domain types with no AWS SDK dependency.
Structs
- Authorization
Decision - Authorization decision from policy evaluation.
- OpenAPI
Server Entity - Server configuration for OpenAPI Code Mode.
- Operation
Entity - Operation entity for policy evaluation.
- Script
Entity - Script entity for policy evaluation (OpenAPI Code Mode).
- Server
Config Entity - Server configuration for policy evaluation.
- SqlServer
Entity - Server configuration for SQL Code Mode.
- Statement
Entity - SQL statement entity for policy evaluation (SQL Code Mode).
Functions
- get_
baseline_ policies - Get the baseline Cedar policies.
- get_
code_ mode_ schema_ json - Get the Cedar schema in JSON format.
- get_
openapi_ baseline_ policies - Get baseline Cedar policies for OpenAPI Code Mode.
- get_
openapi_ code_ mode_ schema_ json - Get the Cedar schema for OpenAPI Code Mode in JSON format.
- get_
sql_ baseline_ policies - Get baseline Cedar policies for SQL Code Mode.
- get_
sql_ code_ mode_ schema_ json - Get the Cedar schema for SQL Code Mode in JSON format.
- normalize_
operation_ format - Normalize an operation string to the canonical “METHOD:/path” format.
- normalize_
path_ to_ pattern - Normalize a path to a pattern by replacing numeric/UUID segments with *.